pecos.error\_models.noise\_impl\_old
====================================

.. automodule:: pecos.error_models.noise_impl_old



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.error_models.noise_impl_old.gate_groups
   pecos.error_models.noise_impl_old.init_noise
   pecos.error_models.noise_impl_old.meas_noise
   pecos.error_models.noise_impl_old.memory_noise
   pecos.error_models.noise_impl_old.sq_noise
   pecos.error_models.noise_impl_old.tq_noise
